@@ -47,8 +47,8 @@ use std::sync::Arc;
 use uuid::Uuid;
 use chrono::{Local, Utc};
 use bigdecimal_::BigDecimal;
-use bson2::Bson;
-use bson2::spec::BinarySubtype;
+use rbson::Bson;
+use rbson::spec::BinarySubtype;
 use crate::types::TimestampZ;
 
 /// DataDecoder Process some bson data not yet supported by the framework, which returns TypeInfo and bytes
@@ -850,7 +850,7 @@ impl<'a> DBTx<'a> {
 #[derive(Serialize, Deserialize, Clone, Debug)]
 pub struct DBValue {
     pub type_info: Bson,
-    pub data: Option<bson2::Binary>,
+    pub data: Option<rbson::Binary>,
 }
 
 #[derive(Serialize, Deserialize, Clone, Debug)]
