@@ -99,14 +99,14 @@ impl From<time::ParseError> for crate::Error {
     }
 }
 
-impl From<bson2::ser::Error> for crate::Error {
-    fn from(arg: bson2::ser::Error) -> Self {
+impl From<rbson::ser::Error> for crate::Error {
+    fn from(arg: rbson::ser::Error) -> Self {
         return crate::Error::E(arg.to_string());
     }
 }
 
-impl From<bson2::de::Error> for crate::Error {
-    fn from(arg: bson2::de::Error) -> Self {
+impl From<rbson::de::Error> for crate::Error {
+    fn from(arg: rbson::de::Error) -> Self {
         return crate::Error::E(arg.to_string());
     }
 }
