@@ -1,4 +1,4 @@
-use bson2::{bson, Bson};
+use rbson::{bson, Bson};
 use sqlx_core::column::Column;
 use sqlx_core::decode::Decode;
 use sqlx_core::error::BoxDynError;
@@ -78,7 +78,7 @@ impl RefJsonCodec for Vec<MssqlRow> {
     fn try_to_bson(&self,decoder: &dyn DataDecoder) -> crate::Result<Bson> {
         let mut arr = Vec::with_capacity(self.len());
         for row in self {
-            let mut m = bson2::Document::new();
+            let mut m = rbson::Document::new();
             let columns = row.columns();
             for x in columns {
                 let key = x.name();
