@@ -1,3 +1,4 @@
+use std::any::type_name;
 use std::ops::{Deref, DerefMut};
 use std::str::FromStr;
 use rbson::Bson;
@@ -33,7 +34,12 @@ impl From<&chrono::NaiveDate> for DateNative {
 impl serde::Serialize for DateNative {
     #[inline]
     fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error> where S: Serializer {
-        return serializer.serialize_str(&format!("DateNative({})", self.inner));
+        use serde::ser::Error;
+        if type_name::<S::Error>().eq("rbson::ser::error::Error") {
+            return serializer.serialize_str(&format!("DateNative({})", self.inner));
+        }else{
+            return self.inner.serialize(serializer);
+        }
     }
 }
 
