@@ -1,3 +1,4 @@
+use std::any::type_name;
 use std::fmt::Formatter;
 use std::ops::{Deref, DerefMut};
 use std::str::FromStr;
@@ -32,7 +33,12 @@ impl From<&BigDecimal> for Decimal {
 impl serde::Serialize for Decimal {
     #[inline]
     fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error> where S: Serializer {
-        return serializer.serialize_str(&format!("Decimal({})", self.inner));
+        use serde::ser::Error;
+        if type_name::<S::Error>().eq("rbson::ser::error::Error") {
+            return serializer.serialize_str(&format!("Decimal({})", self.inner));
+        }else{
+            return self.inner.serialize(serializer);
+        }
     }
 }
 
